@@ -445,7 +445,7 @@ class SFINCS:
     def read_timeseries_output(self, name_list = None, file_name = None):
     
         # Returns a dataframe with timeseries
-        if self.input.outputformat[0:2] == "bin":
+        if self.input.outputformat[0:3] == "bin":
             
             # ASCII output
     
@@ -509,46 +509,56 @@ class SFINCS:
     
         if not zsmax_file:
             zsmax_file = os.path.join(self.path, "zsmax.dat")
+            
 
-        ind_file = os.path.join(self.path, self.input.indexfile)
+        if self.input.outputformat[0:3] == "net":
+            ddd=xr.open_dataset(zsmax_file)
+#            zsmx=ddd.zsmax.values
+            zsmax=ddd.zsmax.values.max(axis=0)
+            return zsmax
 
-        freqstr = str(self.input.dtmaxout) + "S"
-        output_times = pd.date_range(start=self.input.tstart,
-                                     end=self.input.tstop,
-                                     freq=freqstr).to_pydatetime().tolist()
-        nt = len(output_times)
-        
-        if time_range is None:
-            time_range = [self.input.tstart, self.input.tstop]
-        
-        for it, time in enumerate(output_times):
-            if time<=time_range[0]:
-                it0 = it
-            if time<=time_range[1]:
-                it1 = it
-
-        # Get maximum values
-        nmax = self.input.nmax
-        mmax = self.input.mmax
-                        
-        # Read sfincs.ind
-        data_ind = np.fromfile(ind_file, dtype="i4")
-        npoints  = data_ind[0]
-        data_ind = np.squeeze(data_ind[1:])
-        
-        # Read zsmax file
-        data_zs = np.fromfile(zsmax_file, dtype="f4")
-        data_zs = np.reshape(data_zs,[nt, npoints + 2])[it0:it1+1, 1:-1]
-        data_zs = np.amax(data_zs, axis=0)
-        
-        if output=="grid":
-            zs_da = np.full([nmax*mmax], np.nan)        
-            zs_da[data_ind - 1] = np.squeeze(data_zs)
-            zs_da = np.where(zs_da == -999, np.nan, zs_da)
-            zs_da = np.transpose(np.reshape(zs_da, [mmax, nmax]))
-            return zs_da
         else:
-            return data_zs
+        
+            ddd=xr.open_dataset(zsmax_file)
+            ind_file = os.path.join(self.path, self.input.indexfile)
+    
+            freqstr = str(self.input.dtmaxout) + "S"
+            output_times = pd.date_range(start=self.input.tstart,
+                                         end=self.input.tstop,
+                                         freq=freqstr).to_pydatetime().tolist()
+            nt = len(output_times)
+            
+            if time_range is None:
+                time_range = [self.input.tstart, self.input.tstop]
+            
+            for it, time in enumerate(output_times):
+                if time<=time_range[0]:
+                    it0 = it
+                if time<=time_range[1]:
+                    it1 = it
+    
+            # Get maximum values
+            nmax = self.input.nmax
+            mmax = self.input.mmax
+                            
+            # Read sfincs.ind
+            data_ind = np.fromfile(ind_file, dtype="i4")
+            npoints  = data_ind[0]
+            data_ind = np.squeeze(data_ind[1:])
+            
+            # Read zsmax file
+            data_zs = np.fromfile(zsmax_file, dtype="f4")
+            data_zs = np.reshape(data_zs,[nt, npoints + 2])[it0:it1+1, 1:-1]
+            data_zs = np.amax(data_zs, axis=0)
+            
+            if output=="grid":
+                zs_da = np.full([nmax*mmax], np.nan)        
+                zs_da[data_ind - 1] = np.squeeze(data_zs)
+                zs_da = np.where(zs_da == -999, np.nan, zs_da)
+                zs_da = np.transpose(np.reshape(zs_da, [mmax, nmax]))
+                return zs_da
+            else:
+                return data_zs
             
         
 #     def write_hmax_geotiff(self, dem_file, index_file, hmax_file, time_range=None, zsmax_file=None):
